CPWindow1::CPWindow1(void)
{
  SetFOwner(this);
  SetClass(wxT("CPWindow"));
  SetName(wxT("window1"));
  SetTag(0);
  SetX(311);
  SetY(212);
  SetWidth(367);
  SetHeight(242);
  SetHint(wxT(""));
  SetEnable(1);
  SetVisible(1);
  SetColor(wxT("#000001"));
  SetPopupMenu(NULL);
  EvMouseButtonPress=EVMOUSEBUTTONPRESS & CPWindow1::_EvMouseButtonPress;
  SetTitle(wxT("simple"));
  SetOverrideRedirect(0);
  //button2
  button2.SetFOwner(this);
  button2.SetClass(wxT("CButton"));
  button2.SetName(wxT("button2"));
  button2.SetTag(0);
  button2.SetX(104);
  button2.SetY(87);
  button2.SetWidth(65);
  button2.SetHeight(28);
  button2.SetHint(wxT("Sub"));
  button2.SetEnable(1);
  button2.SetVisible(1);
  button2.SetColor(wxT("#000001"));
  button2.SetPopupMenu(NULL);
  button2.EvMouseButtonPress=EVMOUSEBUTTONPRESS & CPWindow1::button2_EvMouseButtonPress;
  button2.SetText(wxT("Sub"));
  CreateChild(&button2);
  //button3
  button3.SetFOwner(this);
  button3.SetClass(wxT("CButton"));
  button3.SetName(wxT("button3"));
  button3.SetTag(0);
  button3.SetX(177);
  button3.SetY(87);
  button3.SetWidth(65);
  button3.SetHeight(28);
  button3.SetHint(wxT("Mul"));
  button3.SetEnable(1);
  button3.SetVisible(1);
  button3.SetColor(wxT("#000001"));
  button3.SetPopupMenu(NULL);
  button3.EvMouseButtonPress=EVMOUSEBUTTONPRESS & CPWindow1::button3_EvMouseButtonPress;
  button3.SetText(wxT("Mul"));
  CreateChild(&button3);
  //button4
  button4.SetFOwner(this);
  button4.SetClass(wxT("CButton"));
  button4.SetName(wxT("button4"));
  button4.SetTag(0);
  button4.SetX(251);
  button4.SetY(87);
  button4.SetWidth(65);
  button4.SetHeight(28);
  button4.SetHint(wxT("Div"));
  button4.SetEnable(1);
  button4.SetVisible(1);
  button4.SetColor(wxT("#000001"));
  button4.SetPopupMenu(NULL);
  button4.EvMouseButtonPress=EVMOUSEBUTTONPRESS & CPWindow1::button4_EvMouseButtonPress;
  button4.SetText(wxT("Div"));
  CreateChild(&button4);
  //edit1
  edit1.SetFOwner(this);
  edit1.SetClass(wxT("CEdit"));
  edit1.SetName(wxT("edit1"));
  edit1.SetTag(0);
  edit1.SetX(18);
  edit1.SetY(48);
  edit1.SetWidth(80);
  edit1.SetHeight(26);
  edit1.SetHint(wxT(""));
  edit1.SetEnable(1);
  edit1.SetVisible(1);
  edit1.SetColor(wxT("#000001"));
  edit1.SetPopupMenu(NULL);
  edit1.SetText(wxT(""));
  edit1.SetReadOnly(0);
  CreateChild(&edit1);
  //edit2
  edit2.SetFOwner(this);
  edit2.SetClass(wxT("CEdit"));
  edit2.SetName(wxT("edit2"));
  edit2.SetTag(0);
  edit2.SetX(140);
  edit2.SetY(48);
  edit2.SetWidth(80);
  edit2.SetHeight(26);
  edit2.SetHint(wxT(""));
  edit2.SetEnable(1);
  edit2.SetVisible(1);
  edit2.SetColor(wxT("#000001"));
  edit2.SetPopupMenu(NULL);
  edit2.SetText(wxT(""));
  edit2.SetReadOnly(0);
  CreateChild(&edit2);
  //edit3
  edit3.SetFOwner(this);
  edit3.SetClass(wxT("CEdit"));
  edit3.SetName(wxT("edit3"));
  edit3.SetTag(0);
  edit3.SetX(262);
  edit3.SetY(50);
  edit3.SetWidth(80);
  edit3.SetHeight(26);
  edit3.SetHint(wxT(""));
  edit3.SetEnable(1);
  edit3.SetVisible(1);
  edit3.SetColor(wxT("#000001"));
  edit3.SetPopupMenu(NULL);
  edit3.SetText(wxT("0"));
  edit3.SetReadOnly(1);
  CreateChild(&edit3);
  //label1
  label1.SetFOwner(this);
  label1.SetClass(wxT("CLabel"));
  label1.SetName(wxT("label1"));
  label1.SetTag(0);
  label1.SetX(103);
  label1.SetY(51);
  label1.SetWidth(30);
  label1.SetHeight(20);
  label1.SetHint(wxT(""));
  label1.SetEnable(1);
  label1.SetVisible(1);
  label1.SetColor(wxT("#000001"));
  label1.SetPopupMenu(NULL);
  label1.SetText(wxT("?"));
  label1.SetAlign(1);
  CreateChild(&label1);
  //label2
  label2.SetFOwner(this);
  label2.SetClass(wxT("CLabel"));
  label2.SetName(wxT("label2"));
  label2.SetTag(0);
  label2.SetX(226);
  label2.SetY(53);
  label2.SetWidth(30);
  label2.SetHeight(20);
  label2.SetHint(wxT(""));
  label2.SetEnable(1);
  label2.SetVisible(1);
  label2.SetColor(wxT("#000001"));
  label2.SetPopupMenu(NULL);
  label2.SetText(wxT("="));
  label2.SetAlign(1);
  CreateChild(&label2);
  //button5
  button5.SetFOwner(this);
  button5.SetClass(wxT("CButton"));
  button5.SetName(wxT("button5"));
  button5.SetTag(0);
  button5.SetX(140);
  button5.SetY(129);
  button5.SetWidth(75);
  button5.SetHeight(28);
  button5.SetHint(wxT("Exit Application"));
  button5.SetEnable(1);
  button5.SetVisible(1);
  button5.SetColor(wxT("#000001"));
  button5.SetPopupMenu(NULL);
  button5.EvMouseButtonPress=EVMOUSEBUTTONPRESS & CPWindow1::button5_EvMouseButtonPress;
  button5.SetText(wxT("Exit"));
  CreateChild(&button5);
  //button1
  button1.SetFOwner(this);
  button1.SetClass(wxT("CButton"));
  button1.SetName(wxT("button1"));
  button1.SetTag(0);
  button1.SetX(32);
  button1.SetY(87);
  button1.SetWidth(65);
  button1.SetHeight(28);
  button1.SetHint(wxT("Add"));
  button1.SetEnable(1);
  button1.SetVisible(1);
  button1.SetColor(wxT("#000001"));
  button1.SetPopupMenu(NULL);
  button1.EvMouseButtonPress=EVMOUSEBUTTONPRESS & CPWindow1::button1_EvMouseButtonPress;
  button1.SetText(wxT("Add"));
  CreateChild(&button1);
  //menu1
  menu1.SetFOwner(this);
  menu1.SetClass(wxT("CMenu"));
  menu1.SetName(wxT("menu1"));
  menu1.SetTag(0);
  menu1.SetMenuItems(wxT("File,Help,"));
  CreateChild(&menu1);
  //menu1_File
  menu1_File.SetFOwner(this);
  menu1_File.SetClass(wxT("CPMenu"));
  menu1_File.SetName(wxT("menu1_File"));
  menu1_File.SetTag(0);
  menu1_File.SetText(wxT("File"));
  menu1_File.SetMenuItems(wxT("Exit,"));
  menu1.CreateChild(&menu1_File);
  //menu1_Help
  menu1_Help.SetFOwner(this);
  menu1_Help.SetClass(wxT("CPMenu"));
  menu1_Help.SetName(wxT("menu1_Help"));
  menu1_Help.SetTag(0);
  menu1_Help.SetText(wxT("Help"));
  menu1_Help.SetMenuItems(wxT("About,"));
  menu1.CreateChild(&menu1_Help);
  //menu1_File_Exit
  menu1_File_Exit.SetFOwner(this);
  menu1_File_Exit.SetClass(wxT("CItemMenu"));
  menu1_File_Exit.SetName(wxT("menu1_File_Exit"));
  menu1_File_Exit.SetTag(0);
  menu1_File_Exit.SetText(wxT("Exit"));
  menu1_File_Exit.SetEnable(1);
  menu1_File_Exit.SetSubMenu(NULL);
  menu1_File_Exit.EvMenuActive=EVMENUACTIVE & CPWindow1::menu1_File_Exit_EvMenuActive;
  menu1_File.CreateChild(&menu1_File_Exit);
  //menu1_Help_About
  menu1_Help_About.SetFOwner(this);
  menu1_Help_About.SetClass(wxT("CItemMenu"));
  menu1_Help_About.SetName(wxT("menu1_Help_About"));
  menu1_Help_About.SetTag(0);
  menu1_Help_About.SetText(wxT("About"));
  menu1_Help_About.SetEnable(1);
  menu1_Help_About.SetSubMenu(NULL);
  menu1_Help_About.EvMenuActive=EVMENUACTIVE & CPWindow1::menu1_Help_About_EvMenuActive;
  menu1_Help.CreateChild(&menu1_Help_About);
  /*#Others*/
}
